@@ -5,12 +5,13 @@ rsdepth <- function(pt, q, ...)
 #	if(!is.numeric()) stop ("m must be numeric!");
 
 	rsdepth = .C("rs_depth", 
-                   points=as.double(pt), 
+                   xpoints=as.double(pt[,1]), 
+		   ypoints=as.double(pt[,2]), 
                    query=as.double(q),  
                    depth=double(c(1)),
                    sz=as.integer(length(pt)/2),
                    PACKAGE = "rsdepth")$depth;
-print(rsdepth)
+##print(rsdepth)
 
 ##TODO: report error in case depth is less than 0	
 ##	if(depth < 0) return("There was an error while calculating ");
